/**
 * @description 档案管理相关接口
 */
import request from "@/utils/request";

/**************************客户档案相关接口*********************** */
// 客户档案表格数据接口
export function getUserTableList(data) {
  return request({
    url: "/api/Customer/GetBillList",
    method: "post",
    data,
  });
}
// 客户档案组织列表
export function getUserMenuList(data) {
  return request({
    url: "/api/Classify/GetCusBillList",
    method: "post",
    data,
  });
}
// 省市县
export function GetListByparentID(data) {
  return request({
    url: "/api/Administrative/GetListByparentID",
    method: "post",
    data,
  });
}

// 客户档案保存数据
export function customerSaveData(data) {
  return request({
    url: "/api/Customer/SaveData",
    method: "post",
    data,
  });
}
// 分管部门组织机构树
export function GetOrganTree(data) {
  return request({
    url: "/Api/Organ/GetOrganTree",
    method: "post",
    data,
  });
}
// 当前行详细信息
export function GetBillData(data) {
  return request({
    url: "/api/Customer/GetBillData",
    method: "post",
    data,
  });
}
// 删除
export function DelData(data) {
  return request({
    url: "/api/Customer/DelData",
    method: "post",
    data,
  });
}
// 档案分配所属公司
export function SaveVenDate(data) {
  return request({
    url: "/api/Classify/SaveVenDate",
    method: "post",
    data,
  });
}
// 查询分配所属公司
export function GetDistribute(data) {
  return request({
    url: "/api/Classify/GetCompany",
    method: "post",
    data,
  });
}

/**************************供应商档案相关接口*********************** */
// 供应商列表数据获取
export function vendorGetBillList(data) {
  return request({
    url: "/api/Vendor/GetBillList",
    method: "post",
    data,
  });
}
// 供应商档案保存
export function vendorSaveData(data) {
  return request({
    url: "/api/Vendor/SaveData",
    method: "post",
    data,
  });
}
// 供应商详细信息
export function vendorGetBillData(data) {
  return request({
    url: "/api/Vendor/GetBillData",
    method: "post",
    data,
  });
}
//供应商档案列表删除
export function vendorDelData(data) {
  return request({
    url: "/api/Vendor/DelData",
    method: "post",
    data,
  });
}
/**************************存货档案相关接口*********************** */
// 存货档案树
export function GetInvBillList(data) {
  return request({
    url: "/api/Classify/GetInvBillList",
    method: "post",
    data,
  });
}
// 存货档案列表
export function inventoryGetBillList(data) {
  return request({
    url: "/api/Inventory/GetBillList",
    method: "post",
    data,
  });
}
// 存货档案列表详细信息
export function inventoryGetBillEditList(data) {
  return request({
    url: "/api/Inventory/GetBillData",
    method: "post",
    data,
  });
}

// 存货档案保存
export function inventorySaveData(data) {
  return request({
    url: "/api/Inventory/SaveData",
    method: "post",
    data,
  });
}
// 存货档案删除
export function inventoryDelData(data) {
  return request({
    url: "/api/Inventory/DelData",
    method: "post",
    data,
  });
}
/**************************客户档案 供应商档案 组织机构树*********************** */
// 保存组织机构树
export function classifySaveCusData(data) {
  return request({
    url: "/api/Classify/SaveCusData",
    method: "post",
    data,
  });
}
export function classifyDelCusData(data) {
  return request({
    url: "/api/Classify/DelCusData",
    method: "post",
    data,
  });
}
// 组织机构树详细信息
export function GetCusEditList(data) {
  return request({
    url: "/api/Classify/GetCusBillData",
    method: "post",
    data,
  });
}

/**************************存货档案 组织机构树*********************** */
// 保存组织机构树
export function classifySaveInvData(data) {
  return request({
    url: "/api/Classify/SaveInvData",
    method: "post",
    data,
  });
}
//  删除
export function classifyDelInvData(data) {
  return request({
    url: "/api/Classify/DelInvData",
    method: "post",
    data,
  });
}
// 组织机构树详细信息
export function GetInvEditList(data) {
  return request({
    url: "/api/Classify/GetInvBillData",
    method: "post",
    data,
  });
}

// 存货档案 计量单位
export function dataDictionaryGetBillData(data) {
  return request({
    url: "/api/DataDictionary/GetBillList",
    method: "post",
    data,
  });
}

export function AttachmentsUploadFiles(data) {
  return request({
    url: "/Api/Attachments/UploadFiles",
    method: "post",
    data,
  });
}

/**************************合同阶段档案相关接口*********************** */
// 获取合同阶段档案列表数据
export function contractBillList(data) {
  return request({
    url: "/api/Phase/GetBillList",
    method: "post",
    data,
  });
}
//启用停用-是否开票-是否确认收入
export function switchLock(data) {
  return request({
    url: "/api/Phase/lockState",
    method: "post",
    data,
  });
}
//获取单据列表数据
export function getBillList(data) {
  return request({
    url: "/api/BillMachine/GetBillList",
    method: "post",
    data,
  });
}
//合同档案管理详情的编辑
export function getBillDataRow(data) {
  return request({
    url: "/api/Phase/GetBillData",
    method: "post",
    data,
  });
}
//合同档案保存
export function saveBillList(data) {
  return request({
    url: "/api/Phase/SaveData",
    method: "post",
    data,
  });
}
//合同阶段档案删除
export function delBillList(data) {
  return request({
    url: "/api/Phase/DelData",
    method: "post",
    data,
  });
}
